# Purge Registres Décès INSEE

Ce programme s'adresse essentiellement aux greffiers des pieux,
paroisse et branches de France, de l'Église de Jésus Christ des Saints
des Derniers Jours.

## Objectif

La tenue à jour des registres de l'Église n'est pas une tache
aisée. Une des difficultés est liée au fait que lorsqu'un membre
s'éloigne de l'Église, ses informations personnelles (adresse,
téléphone, etc) ne sont plus mises à jour.

L'INSEE tient un fichier des personnes décédées en France de 1970 à
aujourd'hui. Ce fichier est disponible en [données
ouvertes](https://fr.wikipedia.org/wiki/Donn%C3%A9es_ouvertes) sur [le
site du
gouvernement](https://www.data.gouv.fr/fr/datasets/fichier-des-personnes-decedees/).
Ce fichier est une aubaine, car il permet de savoir si un membre de
l'Église est décédé sans que nous le sachions. Si une personne figure
à la fois dans les registres de l'Église et dans le fichier de
l'INSEE, alors une mise à jour du registre de l'Église est nécessaire.

Parcourir à la main le registre de membres de paroisse est une tache
longue et fastidieuse. Ce programme permet de comparer automatiquement
le registre de paroisse avec le fichier de l'INSEE, et donne la liste
des membres trouvés dans le fichier de l'INSEE.

Le fichier de l'INSEE est actualisé de façon mensuelle. Il semble
intéressant d'utiliser ce programme régulièrement (une fois par an par
exemple) pour s'assurer que les registres restent à jour.

## Pré-requis

### Logiciels
- Git
- Python 3.6+
- Virtualenv

Testé uniquement sur GNU/Linux (Ubuntu 18.4) et Windows

### Données

Le fichier de l'INSEE tel qu'il est présenté n'est pas facile à
exploiter. Je l'ai donc converti en base de donnée SQLite, plus
pratique d'utilisation. Pour le télécharger, [rendez-vous
ici](https://git.roflcopter.fr/sdjgeek/purge-registres-deces-insee/-/wikis/home#t%C3%A9l%C3%A9charger-la-base-de-donn%C3%A9e).

## Installation

### Windows

Utiliser le script ```install.py```

### Linux

- Cloner le code

```bash
git clone -b latest-release https://git.roflcopter.fr/sdjgeek/purge-registres-deces-insee.git
cd purge-registres-deces-insee
```

- Mettre en place l'environnement virtuel Python

```bash
python3 -m venv localenv
source localenv/bin/activate
pip install -r requirements.txt
```

## Utilisation

Aller sur le [site de l'Église](https://lcr.churchofjesuschrist.org),
et se connecter au compte SDJ. Cette étape est essencielle pour que 
le programme puisse accéder aux listes des membres.

Pour lancer le prgramme, vous pouvez double cliquer 
sur ```gui_trouver_decedes.py```, ce qui ouvrira une interface 
graphique.

Si vous préférez la console, vous pouvez aussi faire :

```bash
source localenv/bin/activate
python purge-registres-deces-insee/trouver_deces.py chemin_base_donnees chemin_repertoire_sortie numeros_unites
```

Avec :

- chemin_base_donnees : Le chemin vers le [fichier
  téléchargé](https://git.roflcopter.fr/sdjgeek/purge-registres-deces-insee/-/wikis/home#t%C3%A9l%C3%A9charger-la-base-de-donn%C3%A9e)

- chemin_repertoire_sortie : Le chemin vers le répertoire qui
  contiendra la fichiers de sortie

- numeros_unites : La liste des unités que le programme doit
  tester. La liste commence par le caractère '['. Les numéros d'unités
  sont séparés par des virgules. La liste se termine par le caractère
  ']'. Par exemple [47823, 67745, 31456]

Le script devrait trouver seul le cookie de session permettant de
consulter la liste des membres. Mais en cas d'échec, il est possible
de lui donner le chemin vers le fichier SQLite que Firefox utilise
pour stocker les cookies avec l'option '-c'. En règle générale ce
fichier se trouve le répertoire :

- sur linux :
  "~/.mozilla/firefox/<un_code_étrange>.default/cookies.sqlite"

- sur windows :
  "C:\Users\<nom_utilisateur>\AppData\Local\Mozilla\Firefox\Profiles\<un_code_étrange>.default\cookies.sqlite"

Par exemple :

```bash
python purge-registres-deces-insee/trouver_deces.py ~/Documents/fichier-des-personnes-decedees.sqlite ~/Documents/ 123,854 -c ~/.mozilla/firefox/8h3jsedf.default/cookies.sqlite
```

Le script mettra un peu de temps à s'exécuter. En fin d'exécution, le
fichier liste_membres_decedes_unite_{unite}.txt contiendra la liste
des membres trouvés dans le fichier de l'INSEE. Il est recommandé de
contrôler les informations du membres avant de le déclarer comme
décédé dans les registres de l'Église.

## Licence

Copyright (c) 2020 Sdj Geek

Ce logiciel est sous licence MIT/X Consortium. Elle donne à toute
personne recevant le logiciel (et ses fichiers) le droit illimité de
l'utiliser, le copier, le modifier, le fusionner, le publier, le
distribuer, le vendre et le "sous-licencier" (l'incorporer dans une
autre licence). La seule obligation est d'incorporer la notice de
licence et de copyright dans toutes les copies. Voir le fichier
[LICENSE](LICENSE) pour le texte complet.
